@@ -11,12 +11,18 @@ from importlib.abc import MetaPathFinder
 from importlib.machinery import ExtensionFileLoader
 
 LOADING_STACK = []
+LIB_EXTS = [".pyd", ".so"]
 
 def find_lib_path(paths, vtk_module_name):
-    for ext in [".pyd", ".so"]:
+    for ext in LIB_EXTS:
         for base_path in paths:
-            for f in Path(base_path).glob(f"{vtk_module_name}.*{ext}"):
-                return str(f.resolve())
+            # vtk-wheel => vtkCommonCore.cpython-310-darwin.so
+            # paraview  => vtkCommonCore.so
+            # Caution: vtkIOXML vs vtkIOXMLParser
+            for f in Path(base_path).glob(f"{vtk_module_name}[.-]*"):
+                resolved_file = f.resolve()
+                if resolved_file.is_file() and ext in resolved_file.suffixes:
+                    return str(resolved_file)
 
 
 class VTKMetaHook(MetaPathFinder):
@@ -163,6 +169,8 @@ __all__ = [
     'vtkRenderingMatplotlib',
     'vtkRenderingLOD',
     'vtkRenderingImage',
+    'vtkChartsCore',
+    'vtkRenderingGridAxes',
     'vtkIOMovie',
     'vtkIOVideo',
     'vtkIOFFMPEG',
@@ -204,6 +212,7 @@ __all__ = [
     'vtkIOMPIImage',
     'vtkIOMINC',
     'vtkIOLAS',
+    'vtkIOLANLX3D',
     'vtkIOImport',
     'vtkIOIOSS',
     'vtkIOHDF',
@@ -225,6 +234,7 @@ __all__ = [
     'vtkIOCesium3DTiles',
     'vtkIOCONVERGECFD',
     'vtkIOCGNSReader',
+    'vtkIOAvmesh',
     'vtkIOAsynchronous',
     'vtkIOAlembic',
     'vtkIOAMR',
@@ -276,7 +286,6 @@ __all__ = [
     'vtkDomainsChemistryOpenGL2',
     'vtkCommonPython',
     'vtkCommonArchive',
-    'vtkChartsCore',
     'vtkCommonColor',
     'vtkImagingSources',
     'vtkInfovisCore',
@@ -296,7 +305,7 @@ __all__ = [
 ]
 #------------------------------------------------------------------------------
 # get the version
-__version__ = "9.4.2"
+__version__ = "9.5.0"
 
 #------------------------------------------------------------------------------
 # describe import dependencies to properly define Python @override
